# DendroTweaks

<img src="https://dendrotweaks.readthedocs.io/en/latest/_static/logo.png" width="25%">
<p>

**DendroTweaks** is a Python toolbox designed for creating and validating single-cell biophysical models with active dendrites. 

It is available both as a standalone Python package and a web-based application.

## Learn More

- **Standalone Library**: Explore the [official documentation](https://dendrotweaks.readthedocs.io/en/latest/index.html) for detailed tutorials and API reference.
- **Web Application**: Access the GUI online via our platform at [dendrotweaks.dendrites.gr](https://dendrotweaks.dendrites.gr).
- **Quick Overview**: Check out our [e-poster](https://doi.org/10.57736/abba-7149), including a video demonstration, presented at the FENS Forum 2024 in Vienna.

## Publication

For an in-depth understanding of DendroTweaks, refer to our publication in *eLife*:

> Roman Makarov, Spyridon Chavlis, Panayiota Poirazi (2024).  
> *DendroTweaks: An interactive approach for unraveling dendritic dynamics.*  
> eLife 13:RP103324. [https://doi.org/10.7554/eLife.103324.1](https://doi.org/10.7554/eLife.103324.1)

If you find DendroTweaks helpful for your research, please consider citing our work:

```bibtex
@article{Makarov2024,
    title={DendroTweaks: An interactive approach for unraveling dendritic dynamics},
    author={Makarov, Roman and Chavlis, Spyridon and Poirazi, Panayiota},
    journal={eLife},
    volume={13},
    pages={RP103324},
    year={2024},
    doi={10.7554/eLife.103324.1}
}
```